var catchAsync = function catchAsync(fn) {
  return function (req, res, next) {
    Promise.resolve(fn(req, res, next))["catch"](function (err) {
      return next(err);
    });
  };
};

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };
  return _extends.apply(this, arguments);
}

var httpStatus = /*#__PURE__*/require('http-status');

var ApiError = /*#__PURE__*/require('./ErrorClass');

var errorConverter = function errorConverter(err, _req, _res, next) {
  var error = err;

  if (!(error instanceof ApiError)) {
    var statusCode = error.statusCode || httpStatus.BAD_REQUEST;
    var message = error.message || httpStatus[statusCode];
    error = new ApiError(statusCode, message, false, err.stack);
  }

  next(error);
};
var errorHandler = function errorHandler(err, _req, res, _next) {
  var statusCode = err.statusCode,
      message = err.message;

  if (process.env.NODE_ENV === 'production' && !err.isOperational) {
    statusCode = httpStatus.INTERNAL_SERVER_ERROR;
    message = httpStatus[httpStatus.INTERNAL_SERVER_ERROR];
  }

  res.locals.errorMessage = err.message;

  var response = _extends({
    code: statusCode,
    message: message
  }, process.env.NODE_ENV === 'development' && {
    stack: err.stack
  });

  res.status(statusCode).send(response);
};

var asyncHandle = function asyncHandle(fn) {
  Promise.resolve(fn(arguments))["catch"](function () {
    return 'err';
  });
};

export { asyncHandle, catchAsync, errorConverter, errorHandler };
//# sourceMappingURL=async-handler-express.esm.js.map
